@@ -2,7 +2,7 @@ package MooseX::ShortCut::BuildInstance::Types;
 BEGIN {
   $MooseX::ShortCut::BuildInstance::Types::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv("v1.28.6");
+use version; our $VERSION = qv("v1.32.2");
 use strict;
 use warnings;
 use Data::Dumper;
@@ -28,9 +28,6 @@ if( $try_xs and exists $INC{'Type/Tiny/XS.pm'} ){
 		die "You have loaded Type::Tiny::XS but versions prior to 0.010 will cause this module to fail";
 	}
 }
-if( $ENV{ Smart_Comments } ){
-	use Smart::Comments -ENV;#'###'
-}
 
 #########1 Package Variables  3#########4#########5#########6#########7#########8#########9
 
